/* 
  UserCellEditor.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  07-OCT-1996

*/

#import "CellEditor.h"

@interface UserCellEditor : CellEditor

-createEnd;   // Overridden...
-update;      // Overridden...

@end

